@@ -1,15 +1,11 @@
 #! /usr/bin/python3
 
 import traceback
-import warnings
-from datetime import date, datetime, timedelta
+from datetime import datetime, timedelta
 
 import pandas as pd
 import requests
 
-# https://docs.python.org/3/library/datetime.html#strftime-and-strptime-format-codes
-
-# HDDF = 'holidays.csv'
 HOLIDAYS = [
     "01/01/2015", "01/02/2015", "01/03/2015",
     "02/18/2015", "02/19/2015", "02/20/2015", "02/21/2015", "02/22/2015", "02/23/2015", "02/24/2015",
