@@ -23,6 +23,11 @@ class TestPitrading(unittest.TestCase):
 
     def test_000_something(self):
         """Test something."""
-        Instrument('20220726', suffix='csi').get_contract_mapping()
+        Instrument('20220724', suffix='8am').get_contract_mapping()
+        Instrument('20220724', suffix='com').get_contract_mapping()
+        Instrument('20220724', suffix='prod').get_contract_mapping()
+        Instrument('20220724', suffix='pi_sim').get_contract_mapping()
+        Instrument('20220724', suffix='hilvg').get_contract_mapping()
+        Instrument('20220724', suffix='csi').get_contract_mapping()
             
         
\ No newline at end of file
